#! /bin/sh
# Script to build a Slackware package for wxGTK-2.5.3 (needed for wxmaxima)
# You must have wxGTK-2.5.3.tar.bz2 in the current directory.
# This script may fail if the path pointing to the current directory
# contains special character (such as space,...). It has been tested with the full
# installation of Slackware 10.0 
# This script is in the public domain 
# Author (of this script): Olivier Esser, olive_esseret@yahoo.com)


SRC=wxGTK-2.5.3.tar.bz2
PKGNAME=wxgtk-2.5.3-i486-1.tgz
BUILDSCRIPT=/usr/src/slackbuilds/wxGTK-2.5.3/build.sh
PKGSNAME=wxgtk
INSTALLDIR=/usr
DOC=$INSTALLDIR/doc/wxGTK-2.5.3

error() {
    echo "$1 failed, exiting..." 1>&2
    exit 1
}

# Strip recursively all files and libraries in the given directory
stripall() {
    for f in `find $1 -type f` ; do
	if file $f | grep -q 'not stripped' ; then
	    strip -s $f
	fi
    done
}


umask 0022
export CFLAGS="-march=i486"
export CXXFLAGS="-march=i486"
BUILD=/tmp/wxgtk.build
PKG=/tmp/wxgtk.pkg
rm -rf -- $BUILD $PKG
mkdir $BUILD
mkdir $PKG
CURDIR=$PWD
cd $BUILD
tar -jxf $CURDIR/$SRC
# cd to the directory tar has created
cd *
./configure --prefix=$INSTALLDIR || error configure
make || error make
make install DESTDIR=$PKG || error "make install"
chown -R root:bin $PKG/$INSTALLDIR/bin
mkdir -p $PKG/$DOC
cp CHANGES-GTK.txt CHANGES.txt COPYING.LIB INSTALL.txt config.log LICENCE.txt README-GTK.txt README.txt TODO.txt $PKG/$DOC
cp $CURDIR/wxgtk-2.5.3-i486-1.txt $PKG/$DOC/README.Slackware-package 
cd $CURDIR
mkdir -p `dirname $PKG/$BUILDSCRIPT`
cp $0 $PKG/$BUILDSCRIPT
cd $PKG
stripall .
mkdir install
cat > install/slack-desc <<EOF
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

      |-----handy-ruler------------------------------------------------------|
wxgtk: wxWidgets, An open source C++ GUI framework.
wxgtk:
wxgtk: wxWidgets gives you a single, easy-to-use API for writing GUI
wxgtk: applications on multiple platforms. Link with the appropriate library 
wxgtk: for your platform (Windows/Unix/Mac, others coming shortly) and 
wxgtk: compiler (almost any popular C++ compiler), and your application will
wxgtk: adopt the look and feel appropriate to that platform. This package
wxgtk: provides the GTK version of wxWidgets.
wxgtk: 
wxgtk: This package has been made primarily to satisfy a dependency
wxgtk: with wxmaxima
EOF
cat > $PKG/install/doinst.sh <<EOF
#! /bin/sh
ldconfig
EOF
chmod a+x $PKG/install/doinst.sh
cd $PKG
makepkg -l n -c n $CURDIR/$PKGNAME
